#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-dns-z-dns-internal
version:              4.0.1
package-name:         dns
lib-name:             dns-internal
id:                   dns-4.0.1-ElKACw9nNA37xV0mBhnBvk-dns-internal
key:                  dns-4.0.1-ElKACw9nNA37xV0mBhnBvk-dns-internal
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  8731a771453cf57dda7baaaef9ed2d22
exposed-modules:
    Network.DNS.Base32Hex Network.DNS.Decode.Internal
    Network.DNS.Decode.Parsers Network.DNS.Encode.Builders
    Network.DNS.Encode.Internal Network.DNS.Imports Network.DNS.Memo
    Network.DNS.Resolver.Internal Network.DNS.StateBinary
    Network.DNS.Types.Internal Network.DNS.Types.Resolver

import-dirs:          /usr/lib/ghc-8.10.5/site-local/dns-4.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/dns-4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/dns-4.0.1
hs-libraries:         HSdns-4.0.1-ElKACw9nNA37xV0mBhnBvk-dns-internal
depends:
    array-0.5.4.0 async-2.2.3-EEZ7ScAbhsHIRG0TBpna8H
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib
    auto-update-0.1.6-7K4JToCmNkHJlkSexgjzA2 base-4.14.2.0
    base16-bytestring-1.0.1.0-HvKbW9RCiAQ5xlJPICEukR
    base64-bytestring-1.2.0.1-9folcSD81CwJ7ibR6pZE7R
    bytestring-0.10.12.0 containers-0.6.4.1
    cryptonite-0.29-KSQcZnQaH5M3lIm9Vzc7YS
    hourglass-0.2.12-9iZsbaT4CVFLnJ2S83W47g
    iproute-1.7.11-d5s0fig5u67LjOGRvUkdk mtl-2.2.2
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M
    psqueues-0.2.7.2-JTDb6i4jgYCAzVhYduMDiO

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dns
version:              4.0.1
visibility:           public
id:                   dns-4.0.1-8rmSjSLgtXpC3o7a9j99nO
key:                  dns-4.0.1-8rmSjSLgtXpC3o7a9j99nO
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             DNS library in Haskell
description:
    A thread-safe DNS library for both clients and servers written
    in pure Haskell.

category:             Network
abi:                  69bb7db9e74bf8bd0775b9805dce91d8
exposed:              True
exposed-modules:
    Network.DNS Network.DNS.Decode Network.DNS.Encode Network.DNS.IO
    Network.DNS.Lookup Network.DNS.LookupRaw Network.DNS.Resolver
    Network.DNS.Types Network.DNS.Utils

hidden-modules:       Network.DNS.Transport
import-dirs:          /usr/lib/ghc-8.10.5/site-local/dns-4.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/dns-4.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/dns-4.0.1
hs-libraries:         HSdns-4.0.1-8rmSjSLgtXpC3o7a9j99nO
depends:
    array-0.5.4.0 async-2.2.3-EEZ7ScAbhsHIRG0TBpna8H
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib
    auto-update-0.1.6-7K4JToCmNkHJlkSexgjzA2 base-4.14.2.0
    base16-bytestring-1.0.1.0-HvKbW9RCiAQ5xlJPICEukR
    base64-bytestring-1.2.0.1-9folcSD81CwJ7ibR6pZE7R
    bytestring-0.10.12.0 containers-0.6.4.1
    cryptonite-0.29-KSQcZnQaH5M3lIm9Vzc7YS
    dns-4.0.1-ElKACw9nNA37xV0mBhnBvk-dns-internal
    hourglass-0.2.12-9iZsbaT4CVFLnJ2S83W47g
    iproute-1.7.11-d5s0fig5u67LjOGRvUkdk mtl-2.2.2
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M
    psqueues-0.2.7.2-JTDb6i4jgYCAzVhYduMDiO

haddock-interfaces:   /usr/share/doc/haskell-dns/html/dns.haddock
haddock-html:         /usr/share/doc/haskell-dns/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

